<?php

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: DISABLED.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: DISABLED.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * regions[page_top] = Page top
 * regions[header] = Header
 * regions[preface_first] = Preface First
 * regions[preface] = Preface Middle
 * regions[preface_last] = Preface Last
 * regions[highlighted] = Highlighted
 * regions[help] = Help
 * regions[title_prefix] = Page title prefix
 * regions[title_suffix] = Page title suffix
 * regions[content_first] = Content First
 * regions[content] = Content
 * regions[content_last] = Content last
 * regions[secondary] = Secondary Middle
 * regions[tertiary] = Tertiary Middle
 * regions[postscript_first] = Postscript First
 * regions[postscript] = Postscript Middle
 * regions[postscript_last] = Postscript Last
 * regions[navigation] = Navigation
 * regions[footer] = Footer
 * regions[page_bottom] = Page bottom
 *
 * 
 * 	$region_classes = array(); // array of classes keyed by region name
 *  $inner_classes = array(); // array of classes keyed by region name
 * 
 * 
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 */
$plink = Plink::singleton();


?>
<!DOCTYPE html>
<html lang="<?php print $language->language; ?>" version="HTML+RDFa 1.1" dir="<?php print $language->dir; ?>" class="no-js">
<head>
	<title><?php print $head_title; ?></title>
	<?php print $head; ?>
	<?php print $styles; ?>
	<?php print $media_query_css; ?>
	<?php print $scripts; ?>
</head>
<body id="<?php print 'lang-' . $language->language; ?>" class="<?php print $body_classes;?>">
  
  <div id="skip-links">
     <a href="#ank-main-content" class="element-invisible element-focusable"><?php print t('Skip to main content'); ?></a>
     <a href="#ank-main-navigation" class="element-invisible element-focusable"><?php print t('Skip to main navigation'); ?></a>
   </div>

<!-- Start MOBILE THEME. //-->

	<div id="container" class="content-container clearfix" data-role="page">
		
		<div data-role="header" data-fullscreen="true" data-theme="d" class="clearfix header-wrapper">
    	<?php print $title_prefix; ?>
  		<h1 class="title" id="page-title"><?php print $title; ?></h1>
  		<?php print $title_suffix; ?>
	 </div>

		
		<?php if($navigation): ?>
      <nav id="main-navigation" class="clearfix" style="clear:both;" data-role="navigation">
     		<a id="ank-main-navigation"></a>
     		<div class="region-inner" data-role="navbar">
        		<?php print $navigation; ?>
     		</div>
     	</nav> <!-- /main-navigation //-->		
    <?php endif; ?>

		<?php if($header): ?>
  	<div class="header clearfix">
  		<div class="region-inner">
  	    <?php print $header; ?>			
  		</div>
    </div>  
    <?php endif; ?>
  	
		<div id="primary" class="clearfix" data-role="content">
			
			<?php if($site_name): ?>
			 <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="site-name">
				<span><?php print $site_name; ?></span>
			</a>
			<?php endif; ?>
			
			<header id="content-first" class="clearfix">
				
				<?php if ($highlighted): ?>
					<div id="highlighted" class="clearfix"><?php print $highlighted; ?></div>
				<?php endif; ?>
        
        <?php if ($tabs): ?>
					<nav class="tabs clear clearfix"><?php print $tabs; ?></nav>
				<?php endif; ?>

        <?php print $help; ?>

			</header> <!-- /primary > header //-->
			
			<?php print $messages; ?>
			
			<!-- Content First Region //-->
			<?php print $content_first; ?>
			<!-- END content first region //-->
			
			<!-- START MAIN CONTENT //-->
			<a id="ank-main-content"></a>
			<?php print $content; ?>
			<!-- END MAIN CONTENT //-->
			
			<footer id="content-last" class="clearfix">
				<?php print $content_last; ?>
				<?php print $feed_icons; ?>
			</footer><!-- /primary > footer //-->
			
		</div> <!-- /primary //-->
	  <div class="footer clearfix" data-theme="d" data-role="footer" data-fullscreen="true" >
   		<div class="region-inner">
    		<?php print $footer; ?>
   		</div>
     </div>

	</div><!-- /container --> 


	

<!-- END PAGE TPL //-->
</body>
</html>