<?php

/**
 * Start your engines!
 * This class is required because it contains the core processing of the plink system
 **/ 
require_once(dirname(__FILE__) . '/engine/plink.class.php');

/** 
 * Default scripts and styles
 **/ 
drupal_add_css(drupal_get_path('theme', 'plink') . '/css/defaults.css', 'module');
drupal_add_js(drupal_get_path('theme', 'plink') . "/js/modernizr-2.0.js", 'module');

if(module_exists('skinr')){
  drupal_add_css(drupal_get_path('theme', 'plink') . '/skins/core/skinr.css', 'module');  
}


// ////////////////////////////////////////////////////////////////////////////////////////////////
// Preprocess Hooks
// ////////////////////////////////////////////////////////////////////////////////////////////////


/**
 * Preprocess function 
 **/
function plink_preprocess(&$vars) { }


/**
 * Preprocess function 
 * Maintained from D7 backport
 **/
function plink_preprocess_html(&$vars) {
	$plink = Plink::singleton();
	
	// Extend some helpful body classes
	
	$body_classes = $plink->get_body_classes();	
  $vars['classes_array'] = array();
	
	if (isset($vars['node'])) { 
	  $n = $vars['node'];
	  $vars['classes_array'][] = ($vars['node']) ? 'full-node' : ''; 	  
	  $vars['classes_array'][] = 'node-' . $n->nid;
	  if(isset($n->path)) {
	    $vars['classes_array'][] = $plink->drupal_clean_css_identifier($n->path);
	  }
	
	}
	
	// Lets do some fun useragent stuff to add special classes.
	// This does pretty much what the browser class module does but 
	// Because there is a bit of a reliance on the fact that the ie
	// classes show up we need to add it here
	// CODE CREDIT: to the author of the browserclass module. hosszukalman :D
	
	if(!module_exists('browserclass')) {
		$agent = strtolower($_SERVER['HTTP_USER_AGENT']);

		  if (stristr($agent, 'msie') !== FALSE) {
		    $vars['classes_array'][] = 'ie';

		    // Add ie extra class with the version number
		    $pattern = '/.*msie ([0-9]*)\..*/';
		    $matches = array();

		    preg_match($pattern, $agent, $matches);
		    if ($matches[1]) {
		      $vars['classes_array'][] = 'ie' . $matches[1];
		    }
		  }
	}
	
	
	//Add the apple touch icon to the header
	if ($plink->theme_settings()->enable_apple_touch) {	  
	  $head = '<link rel="shortcut icon" href=" ' . url($plink->theme_settings()->apple_touch_icon_path,array('absolute' => TRUE)) .'" />'; 
    drupal_set_html_head($head);
  	$variables['head'] = drupal_get_html_head();	  
	}
	  
	
	  $body_classes = array_merge($body_classes, $vars['classes_array']);
		$vars['body_classes'] .= ' ' . implode(' ', $body_classes);
	  $vars['body_classes'] = trim($vars['body_classes']);
}


function plink_preprocess_page(&$vars) { 	
	
	// Initialize engine
	// Process!
  $plink = Plink::singleton();
  $plink->init_processes();  
	
	// Backport from Drupal 7
	plink_preprocess_html($vars);
	
	$vars['container_classes'] = '';
	$vars['primary_classes'] = '';
	$vars['secondary_classes'] = '';
	$vars['tertiary_classes'] = '';
	$vars['region_classes'] = array();
	$vars['inner_classes'] = array();
	
	
	// Grid Based layouts
	if($plink->is_grid()) {
		$vars['primary_classes'] .= $plink->get_content_region_classes('primary');
		$vars['secondary_classes'] .= $plink->get_content_region_classes('secondary');
		$vars['tertiary_classes'] .= $plink->get_content_region_classes('tertiary');
		$vars['container_classes'] .= $plink->get_main_region_classes();
	
		$regions = system_region_list($plink->theme);
	  foreach($regions as $k => $v) {
	   	$vars['region_classes'][$k] = $plink->get_region_classes($k);
  		$vars['inner_classes'][$k] = $plink->get_region_inner_classes($k); 
	  }
	} 
		
	//Set the breadcrumbs flag
	$vars['breadcrumbs_enabled'] = $plink->theme_settings()->enable_breadcrumbs;		
	$vars['media_query_css'] = $plink->get_media_query_css();
	
	// little hacky hack to get the css back up to snuff
	$vars['css'] = drupal_add_css();
  $vars['styles'] = drupal_get_css();	

  // Add per content type page template suggestions
  if (isset($vars['node'])) {
    // Add template naming suggestion. It should alway use hyphens.
    // If node type is "custom_news", it will pickup "page-custom-news.tpl.php".
    $vars['template_files'][] = 'page-'. str_replace('_', '-', $vars['node']->type);
  }
  
}

/**
 * Preprocess function 
 **/
// function plink_preprocess_region(&$vars) {
//  $plink = Plink::singleton();
//  $vars['inner_classes'] = '';
//  
//  // add grid classes to the regions if grid is enabled
//  if($plink->is_grid()) {
//    $vars['classes_array'][] = $plink->get_region_classes($vars['region']);
//    $vars['inner_classes'] = $plink->get_region_inner_classes($vars['region']);
//  } 
// }

/**
 * Preprocess function 
 **/
// function plink_preprocess_maintenance_page(&$vars) { }


/**
 * Preprocess function 
 **/
function plink_preprocess_node(&$vars) { 
	$node_classes = array();
	global $user;
	$plink = Plink::singleton();
	
	$vars['node_classes'] = array();	
		
	// Lets add some classes to the node 	
  if ($vars['sticky']) {
		$node_classes[] = 'sticky';
	}
	if ($vars['promote']) {
		$node_classes[] = 'promoted';
	}
	if (!$vars['node']->status) {
		$node_classes[] = 'node-unpublished';
		$vars['unpublished'] = TRUE;
	}
	else {
		$vars['unpublished'] = FALSE;
	}
	if ($vars['node']->uid && $vars['node']->uid == $user->uid) {
		// Node is authored by current user
		$node_classes[] = 'user-me';
	}
	//Add node's user id
	$node_classes[] = 'user-' . $vars['node']->uid;
	
	if ($vars['teaser']) {
		// Node is displayed as teaser
		$node_classes[] = 'node-teaser';
	}
	else {
		$node_classes[] = 'node-full';
	}
	//odd/even class for node listings
	$node_classes[] = $vars['zebra'];
	//node count for node listings
	$node_classes[] = 'count-' . $vars['id'];
	// Class for node type: "node-type-page", "node-type-story", "node-type-my-custom-type", etc.
	$node_classes[] = 'node node-type-'. $vars['node']->type;
	
	$vars['node_classes'] = implode(array_merge($vars['node_classes'], $node_classes), " ");
	
	//Add custom meta info
  if($plink->theme_settings()->enable_meta_info) {
   $vars['submitted'] = token_replace($plink->theme_settings()->meta_info_string, array('node' => $vars['node']));
  }
  
}


/**
 * Preprocess function 
 **/
function plink_preprocess_block(&$vars) { 
	$plink = Plink::singleton();

	$block_classes = $plink->get_block_classes($vars);	
	$block_classes[] = 'block block-'. $vars['block']->module;
  $block_classes[] = $vars['block_zebra'];
  $block_classes[] = 'region-count-'. $vars['block_id'];
  
  $vars['block_classes'] = implode(' ', $block_classes);
}


/**
 * Preprocess function 
 **/
function plink_preprocess_comment(&$vars) {
  static $comment_counter = array();
  static $comment_odd = TRUE;
  $plink = Plink::singleton();

  /* TODO BACKPORT THIS */

  // if (!isset($comment_counter[$vars['node']->nid])) {
  //    $comment_counter[$vars['node']->nid] = 1;
  //  }
  //  // Add to array of handy comment classes
  //  $vars['classes_array'][] = $comment_odd ? 'odd' : 'even';
  //  $comment_odd = !$comment_odd;
  // 
  //  $vars['classes_array'][] = 'comment-'.$vars['comment']->cid;
  //  $comment_counter[$vars['node']->nid]++;
  // 
  //  // Add classes based on the role(s) of the comment author
  //  $account = user_load($vars['comment']->uid);
  //  foreach ($account->roles as $role) {
  //    $vars['classes_array'][] = "role-".$plink->drupal_clean_css_identifier($role);
  //  }
}


// ////////////////////////////////////////////////////////////////////////////////////////////////
// Process hooks
// ////////////////////////////////////////////////////////////////////////////////////////////////

/**
 * Preprocess function 
 **/
// function plink_process(&$vars, $hook) { }

/**
 * Preprocess function 
 **/
// function plink_process_html(&$vars) { }

/**
 * Preprocess function 
 **/
// function plink_process_page(&$vars) { }

/**
 * Preprocess function 
 **/
// function plink_process_region(&$vars) {}

// function plink_process_node(&$vars) { 
// }

/**
 * Preprocess function 
 **/
// function plink_process_block(&$vars) { }

/**
 * Preprocess function 
 **/
// function plink_process_comment(&$vars) { }


// ////////////////////////////////////////////////////////////////////////////////////////////////
// MISC
// ////////////////////////////////////////////////////////////////////////////////////////////////

/**
 * Add default meta tags to head document
 **/
function plink_add_meta_head(&$vars) {
  $data = array(
    '#tag' => 'meta',
    '#attributes' => array(
      'http-equiv' => "X-UA-Compatible",
      'content' => "IE=edge,chrome=1",
      )
    );
  
  drupal_add_html_head($data,'plink');
}




